#!/bin/bash
# vim: dict=/usr/share/beakerlib/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/patch/Sanity/upstream-test-suite
#   Description: Executes the upstream test suite comming with the package
#   Author: Than Ngo <than@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2010 Red Hat, Inc. All rights reserved.
#
#   This copyrighted material is made available to anyone wishing
#   to use, modify, copy, or redistribute it subject to the terms
#   and conditions of the GNU General Public License version 2.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE. See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public
#   License along with this program; if not, write to the Free
#   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#   Boston, MA 02110-1301, USA.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include rhts environment
. /usr/bin/rhts-environment.sh || exit 1
. /usr/share/beakerlib/beakerlib.sh || exit 1

PACKAGE="doxygen"

rlJournalStart
	rlPhaseStartSetup
		rlAssertRpm $PACKAGE
		rlRun "TmpDir=\$(mktemp -d)" 0 "Creating tmp directory"
		rlRun "cp -a * $TmpDir" 0 "Copy files to $TmpDir"
		rlRun "pushd $TmpDir"
	rlPhaseEnd

	rlPhaseStartTest "test --version"
		rlRun "VERSION=\$( rpm -q --qf '%{VERSION}' doxygen )"
		rlRun -s "doxygen --version"
		rlAssertGrep "${VERSION}" $rlRun_LOG
	rlPhaseEnd

	rlPhaseStartTest "test upstream test suite"
		rlRun "python3 runtests.py >out" 0 "python3 runtests.py"
		rlRun "[ -s out ]" 0 "Output should not be empty"
		rlRun "cat out" 0 "Output of the test suite"
		rlAssertGrep 'All tests passed!' out
	rlPhaseEnd

	rlPhaseStartCleanup
		rlRun "popd"
		rlRun "rm -fr $TmpDir" 0 "Removing tmp directory"
	rlPhaseEnd
rlJournalPrintText
rlJournalEnd
